######################################
R&S SFM TV test transmitter
######################################

.. autoclass:: pymeasure.instruments.rohdeschwarz.sfm.SFM
    :members:
    :show-inheritance:

.. autoclass:: pymeasure.instruments.rohdeschwarz.sfm.Sound_Channel
    :members:
    :show-inheritance:
